@@ -11,31 +11,6 @@ var npm = require('../../')
 // config
 var pkg = path.resolve(__dirname, 'outdated-git')
 var cache = path.resolve(pkg, 'cache')
-
-test('setup', function (t) {
-  setup()
-  t.end()
-})
-
-test('discovers new versions in outdated', function (t) {
-  process.chdir(pkg)
-  t.plan(5)
-  npm.load({cache: cache, registry: common.registry, loglevel: 'silent'}, function () {
-    npm.commands.outdated([], function (er, d) {
-      t.equal('git', d[0][3])
-      t.equal('git', d[0][4])
-      t.equal('git://github.com/robertkowalski/foo-private.git', d[0][5])
-      t.equal('git://user:pass@github.com/robertkowalski/foo-private.git', d[1][5])
-      t.equal('git+https://github.com/robertkowalski/foo', d[2][5])
-    })
-  })
-})
-
-test('cleanup', function (t) {
-  cleanup()
-  t.end()
-})
-
 var json = {
   name: 'outdated-git',
   author: 'Rocko Artischocko',
@@ -49,6 +24,30 @@ var json = {
   }
 }
 
+test('setup', function (t) {
+  setup()
+  t.end()
+})
+
+test('discovers new versions in outdated', function (t) {
+  process.chdir(pkg)
+  t.plan(5)
+  npm.load({cache: cache, registry: common.registry, loglevel: 'silent'}, function () {
+    npm.commands.outdated([], function (er, d) {
+      t.equal(d[0][3], 'git')
+      t.equal(d[0][4], 'git')
+      t.equal(d[0][5], 'git://github.com/robertkowalski/foo-private.git')
+      t.equal(d[1][5], 'git://user:pass@github.com/robertkowalski/foo-private.git')
+      t.equal(d[2][5], 'github:robertkowalski/foo')
+    })
+  })
+})
+
+test('cleanup', function (t) {
+  cleanup()
+  t.end()
+})
+
 function setup () {
   mkdirp.sync(cache)
   fs.writeFileSync(path.join(pkg, 'package.json'), JSON.stringify(json, null, 2), 'utf8')
